# -*- coding: utf-8 -*-

'''
Advanced Interface Switcher Cacher
2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.ui.Cachers import DITPixbufCacher
from advpowcommon.util.singleton import Singleton

class AISCacher(Singleton):

  def __init__(self):
    Singleton.__init__(self)
    self.cacher = DITPixbufCacher(48)

__cacher_singleton = AISCacher()
def get_cacher(): return __cacher_singleton.cacher
